==> dde-network-core_1.0.34.orig.tar.xz: dde-network-core-1.0.34/dock-network-plugin/translations/dock-network-plugin_fa.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="fa" version="2.1">
<context>
    <name>DeviceControllItem</name>
    <message>
        <location filename="../item/netItem.cpp"/>
        <source>Wireless Network</source>
        <translation>شبکه بیسیم</translation>
    </message>
    <message>
        <location filename="../item/netItem.cpp"/>
        <source>Wired Network</source>
        <translation>شبکه کابلی</translation>
    </message>
</context>
<context>
    <name>NetworkPanel</name>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Wired connection: %1</source>
        <translation>اتصال سیمی %1</translation>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Wired Network</source>
        <translation>شبکه کابلی</translation>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Wireless connection: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Wireless Network</source>
        <translation>شبکه بیسیم</translation>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Device disabled</source>
        <translation>دستگاه غیرفعال است</translation>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Network cable unplugged</source>
        <translation>کابل شبکه وصل نشده است</translation>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Not connected</source>
        <translation>متصل نیست</translation>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Connecting</source>
        <translation>در حال اتصال</translation>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Connected but no Internet access</source>
        <translation>متصل است اما دسترسی به اینترنت ندارد</translation>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Disable wired connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Enable wired connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Disable wireless connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Enable wireless connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Disable network</source>
        <translation>غیر فعال کردن شبکه</translation>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Enable network</source>
        <translation>فعال کردن شبکه</translation>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>Network settings</source>
        <translation>تنظیمات شبکه</translation>
    </message>
    <message>
        <location filename="../networkpanel.cpp"/>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <location filename="../networkplugin.cpp"/>
        <source>Network</source>
        <translation>شبکه</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkController</name>
    <message>
        <location filename="../../src/networkcontroller.cpp"/>
        <source>Wired Network</source>
        <translation>شبکه کابلی</translation>
    </message>
    <message>
        <location filename="../../src/networkcontroller.cpp"/>
        <source>Wired Network %1</source>
        <translation>شبکه سیمی %1</translation>
    </message>
    <message>
        <location filename="../../src/networkcontroller.cpp"/>
        <source>Wireless Network</source>
        <translation>شبکه بیسیم</translation>
    </message>
    <message>
        <location filename="../../src/networkcontroller.cpp"/>
        <source>Wireless Network %1</source>
        <translation>شبکه بی سیم %1</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>Hotspot</source>
        <translation>هات اسپات</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>Security Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>Band</source>
        <translation>باند</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>Channel</source>
        <translation>کانال</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>Interface</source>
        <translation>رابط</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>Gateway</source>
        <translation>درگاه</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>Primary DNS</source>
        <translation>DNS اولیه</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>Netmask</source>
        <translation>Netmask</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>Prefix</source>
        <translation>پیشوند</translation>
    </message>
    <message>
        <location filename="../../src/networkdetails.cpp"/>
        <source>Speed</source>
        <translation>سرعت</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceBase</name>
    <message>
        <location filename="../../src/networkdevicebase.cpp"/>
        <source>Disconnected</source>
        <translation>قطع اتصال</translation>
    </message>
    <message>
        <location filename="../../src/networkdevicebase.cpp"/>
        <source>Connecting</source>
        <translation>در حال اتصال</translation>
    </message>
    <message>
        <location filename="../../src/networkdevicebase.cpp"/>
        <source>Authenticating</source>
        <translation>تأیید اعتبار</translation>
    </message>
    <message>
        <location filename="../../src/networkdevicebase.cpp"/>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../src/networkdevicebase.cpp"/>
        <source>Connected</source>
        <translation>متصل شده</translation>
    </message>
    <message>
        <location filename="../../src/networkdevicebase.cpp"/>
        <source>Failed</source>
        <translation>عدم اعمال</translation>
    </message>
    <message>
        <location filename="../../src/networkdevicebase.cpp"/>
        <source>Device disabled</source>
        <translation>دستگاه غیرفعال است</translation>
    </message>
    <message>
        <location filename="../../src/networkdevicebase.cpp"/>
        <source>Connected but no Internet access</source>
        <translation>متصل است اما دسترسی به اینترنت ندارد</translation>
    </message>
    <message>
        <location filename="../../src/networkdevicebase.cpp"/>
        <source>Not connected</source>
        <translation>متصل نیست</translation>
    </message>
    <message>
        <location filename="../../src/networkdevicebase.cpp"/>
        <source>Network cable unplugged</source>
        <translation>کابل شبکه وصل نشده است</translation>
    </message>
    <message>
        <location filename="../../src/networkdevicebase.cpp"/>
        <source>Obtaining IP address</source>
        <translation>در حال به دست آوردن نشانی IP </translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.7.3.orig.tar.xz: dde-network-core-1.1.7.3/dock-network-plugin/translations/dock-network-plugin_fa.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="fa">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>شبکه بیسیم</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>شبکه کابلی</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>شبکه</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>اتصال به شبکه مخفی</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>رمزعبور</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>انصراف</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>اتصال</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>دستگاه غیرفعال است</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>کابل شبکه وصل نشده است</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>متصل نیست</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>در حال اتصال</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>متصل است اما دسترسی به اینترنت ندارد</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable network</source>
        <translation>غیر فعال کردن شبکه</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>فعال کردن شبکه</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>تنظیمات شبکه</translation>
    </message>
</context>
</TS>
